@@ -1,6 +1,6 @@
 package PDL::DSP::Windows;
 
-our $VERSION = '0.007003'; # TRIAL
+our $VERSION = '0.008001'; # TRIAL
 
 use strict;
 use warnings;
@@ -74,6 +74,7 @@ my %symmetric_windows = (
     welch            => 1,
 );
 
+# These are not exported
 my %periodic_windows = (
     bartlett         => 1,
     bartlett_hann    => 1,
@@ -180,16 +181,11 @@ my %window_print_names = (
 
 our @EXPORT_OK = (
     keys %symmetric_windows,
-    keys %periodic_windows,
     qw( window list_windows chebpoly cos_mult_to_pow cos_pow_to_mult ),
 );
 
 $PDL::onlinedoc->scan(__FILE__) if $PDL::onlinedoc;
 
-our %winsubs;
-our %winpersubs;
-our %window_definitions;
-
 =encoding utf8
 
 =head1 NAME
@@ -1509,7 +1505,7 @@ sub tukey {
     barf 'tukey: 2 arguments expected. Got ' . scalar(@_) . ' arguments.' unless @_ == 2;
     my ( $N, $alpha ) = @_;
 
-    barf('tukey: alpha must be between 0 and 1') unless $alpha >=0 and $alpha <= 1;
+    barf('tukey: alpha must be between 0 and 1') unless $alpha >= 0 and $alpha <= 1;
 
     return ones($N) if $alpha == 0;
 
@@ -1530,7 +1526,7 @@ sub tukey_per {
     barf 'tukey: 2 arguments expected. Got ' . scalar(@_) . ' arguments.' unless @_ == 2;
     my ( $N, $alpha ) = @_;
 
-    barf('tukey: alpha must be between 0 and 1') unless $alpha >=0 and $alpha <= 1;
+    barf('tukey: alpha must be between 0 and 1') unless $alpha >= 0 and $alpha <= 1;
 
     return ones($N) if $alpha == 0;
 
@@ -1559,50 +1555,6 @@ sub welch_per {
     1 - zeroes($N)->xlinvals( -1, ( -1 + 1 * ( $N - 1 ) ) / $N ) ** 2;
 }
 
-# Legacy static data
-
-$window_definitions{$_} = {} for keys %symmetric_windows;
-
-$window_definitions{$_}{alias} = [ @{ $window_aliases{$_} } ]
-    for keys %window_aliases;
-
-$window_definitions{$_}{params} = [ @{ $window_parameters{$_} } ]
-    for keys %window_parameters;
-
-$window_definitions{$_}{fn} = $window_names{$_}
-    for keys %window_names;
-
-$window_definitions{$_}{pfn} = $window_print_names{$_}
-    for keys %window_print_names;
-
-%winpersubs = map { $_ => __PACKAGE__->can("${_}_per") } keys %periodic_windows;
-%winsubs    = map { $_ => __PACKAGE__->can($_) } keys %symmetric_windows;
-
-my $wizard = do {
-    my $msg = 'Package variables from PDL::DSP::Windows are deprecated and will be removed in the future.';
-
-    my $read = sub {
-        carp $msg
-            . ' This attempt to read from them will soon become an error';
-    };
-
-    my $write = sub {
-        carp $msg
-            . ' This attempt to write to them will soon become an error';
-    };
-
-    wizard(
-        fetch  => $read,
-        exists => $read,
-        store  => $write,
-        delete => $write,
-    );
-};
-
-cast %winsubs,            $wizard;
-cast %winpersubs,         $wizard;
-cast %window_definitions, $wizard;
-
 =head1 Symmetric window functions
 
 =head2 bartlett($N)
@@ -2127,7 +2079,7 @@ in the Octave signal package.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012-2019 John Lapeyre.
+Copyright 2012-2021 John Lapeyre.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
